@@ -4,8 +4,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILIMPORTER_FILTER_CLAWSMAILS_H
-#define MAILIMPORTER_FILTER_CLAWSMAILS_H
+#pragma once
 
 #include <QHash>
 
@@ -33,4 +32,3 @@ public:
 };
 }
 
-#endif
