@@ -8,8 +8,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILIMPORTER_FILTER_MAILAPP_H
-#define MAILIMPORTER_FILTER_MAILAPP_H
+#pragma once
 
 #include "filters.h"
 namespace MailImporter
@@ -29,9 +28,8 @@ public:
     void importMails(const QString &maildir);
 
 private:
-    FilterMailAppPrivate *const d;
+    std::unique_ptr<FilterMailAppPrivate> const d;
     void traverseDirectory(const QString &);
 };
 }
 
-#endif
